.. image:: https://claimchain.github.io/claimchain.svg
  :width: 50px
  :align: right

claimchain-core documentation
=============================

This is a brief documentation for `claimchain-core`, an experimental prototype
implementation of ClaimChain, a cryptographic data structure. See the
`web page <https://claimchain.github.io>`_ to learn about ClaimChain.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   guide
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
